package dluploadclient;

import java.io.File;

/**
 * Classe qui permet de reprsenter un fichier a uploader
 * 
 * <p>
 * <code>
 * Copyright 2008, Maurer Gilles
 * </code>
 * <p>
 * <code>
 * This file is part of Client dl.free.fr.
 * </code>
 * <p>
 * <code>
 * Client dl.free.fr is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * </code>
 *<p>
 * <code>
 * Client dl.free.fr is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * </code>
 * <p>
 * <code>
 * You should have received a copy of the GNU General Public License
 * along with Client dl.free.fr. If not, see <http://www.gnu.org/licenses/>.
 * </code>
 * 
 * @author Maurer Gilles
 *
 */
public class UploadFile
{

	/**
	 * Le chemin local du fichier
	 */
	private String path;
	
	/**
	 * L'tat du fichier
	 */
	private int state;
	
	/**
	 * L'URL distante du fichier
	 */
	private String url;
	
	/**
	 * Le message d'erreur pour ce fichier (si applicable)
	 */
	private String errorMessage;

	/**
	 * Le pourcentage d'accomplissement du transfert
	 */
	private float percentDone;
	
	
	/**
	 * La taille du fichier
	 */
	private long size;

	/**
	 * Etat du fichier  uploader : En attente
	 */
	public static int WAITING = 10;
	
	/**
	 * Etat du fichier  uploader : En cours d'upload
	 */
	public static int UPLOADING = 20;
	
	/**
	 * Etat du fichier  uploader : Upload
	 */
	public static int UPLOADED = 30;
	
	/**
	 * Etat du fichier  uploader : Erreur
	 */
	public static int ERROR = 50;
	
	/**
	 * Etat du fichier  uploader : Annul par l'utilisateur
	 */
	public static int CANCELLED = 60;
	
	/**
	 * Constructeur par dfaut
	 * @param path Chemin vers le fichier
	 */
	public UploadFile(String path)
	{
		this.path = path;
		this.state = UploadFile.WAITING;
		this.url = new String();
		this.errorMessage = new String();
		this.percentDone = 0;
		this.size = new File(this.path).length();
	}
	
	/**
	 * Retourne l'tat actuel du fichier
	 * @return l'tat actuel du fichier
	 */
	public int getState()
	{
		return state;
	}
	
	/**
	 * Met  jour le statut du fichier
	 * @param state nouveau statut du fichier
	 */
	public void setState(int state)
	{
		this.state = state;
	}
	
	/**
	 * Retourne l'URL du fichier
	 * @return l'URL di fichier
	 */
	public String getUrl()
	{
		return url;
	}
	
	/**
	 * Met  jour l'URL du fichier
	 * @param url l'URL du fichier
	 */
	public void setUrl(String url)
	{
		this.url = url;
	}
	
	/**
	 * Retourne le pourcentage d'accomplissement du transfert
	 * @return le pourcentage d'accomplissement du transfert
	 */
	public float getPercentDone()
	{
		return percentDone;
	}
	
	/**
	 * Retourne le pourcentage d'accomplissement du transfert sous forme de chaines de caractres
	 * @return le pourcentage d'accomplissement du transfert sous forme de chaines de caractres
	 */
	public String getPercentDoneInString()
	{
		return String.format("%.2f", percentDone);
	}
	
	/**
	 * Modifier la valeur du pourcentage d'accomplissement
	 * @param percentDone pourcentage d'accomplissement
	 */
	public void setPercentDone(float percentDone)
	{
		this.percentDone = percentDone;
	}

	/**
	 * Retourne le chemin local du fichier
	 * @return le chemin local du fichier
	 */
	public String getPath()
	{
		return path;
	}

	/**
	 * Modifie le chemin local du fichier
	 * @param path le chemin local du fichier
	 */
	public void setPath(String path)
	{
		this.path = path;
	}
	
	/**
	 * Retourne le statut du fichier sous forme d'une chaine de caractres
	 * @return le statut du fichier sous forme d'une chaine de caractres
	 */
	public String getStateInString()
	{
		if (this.state == UploadFile.WAITING)
		{
			return "En attente";
		}
		else if(this.state == UploadFile.UPLOADED)
		{
			return "Transfr";
		}
		else if (this.state == UploadFile.ERROR)
		{
			return "Erreur : " + this.getErrorMessage();
		}
		else if (this.state == UploadFile.UPLOADING)
		{
			return "Transfert en cours : " + ((String) this.getPercentDoneInString()) + " %";
		}
		else if (this.state == UploadFile.CANCELLED)
		{
			return "Annul par l'utilisateur";
		}
		else
		{
			return "Statut inconnu !";
		}
	}
	
	/**
	 * Retourne le nom de fichier local
	 * @return le nom de fichier local
	 */
	public String getLocalFilename()
	{
		String pathParts[];
		String separator = new String("");
		
		// Il faut chapper le '\' car c'est une expression rgulire qui est  utiliser !
		if(File.separator.compareTo("\\") == 0)
		{
			separator = "\\\\";
		}
		else
		{
			separator = File.separator;
		}
		pathParts = this.getPath().split(separator);
		for (String string : pathParts)
		{
			System.out.println(string);
		}
		return pathParts[pathParts.length-1];
	}
	
	/**
	 * Retourne la taille du fichier
	 * @return la taille du fichier
	 */
	public long getSize()
	{
		return size;
	}
	
	/**
	 * Retourne le message d'erreur du fichier
	 * @return le message d'erreur
	 */
	public String getErrorMessage()
	{
		return errorMessage;
	}

	/**
	 * Modifie le message d'erreur
	 * @param errorMessage le message d'erreur
	 */
	public void setErrorMessage(String errorMessage)
	{
		// Si on met en place un message d'erreur, le statut doit forcment tre mis sur "ERREUR"
		this.setState(UploadFile.ERROR);
		
		this.errorMessage = errorMessage;
	}
}
